==> bbsV0.5.zip: bbs.pl <==

$bbsMaxPage = 10;

# Υեޥå
@week = ('Sun','Mon','Tue','Wed','Thu','Fri','Sat');

$inline_plugin{bbs} = sub {
	my ($session, $bbsName) = @_;
	my %messages = ();
	my $page = $::form{bbspage};

	&puts(sprintf(qq(<form action='%s' method='POST'>
  <table border="0">
    <tr>
      <th align="right">̾</th>
      <td><input type="text" name="name" tabIndex="1"></td>
    </tr>
    <tr>
      <th align="right">̾</th>
      <td><input type="text" name="subject" size="50" tabIndex="2">
        <input type="submit" value="" tabIndex="4"></td>
    </tr>
    <tr>
      <th align="right" valign="top">å</th>
      <td><textarea name="bbsMessage" cols="40" rows="6" tabIndex="3"></textarea></td>
    </tr>
  </table>
  <input type="hidden" name="dummyMessage" value=""/>
  <input type="hidden" name="a" value="bbssubmit"/>
  <input type="hidden" name="bbsName" value="%s"/>
  <input type="hidden" name="p" value="%s"/>
  </form>), $::me, $bbsName, &enc($::form{p})));
	my $bbsEmpty = false;
	open(BBSFP, "+<bbs_$bbsName.cgi") or open(BBSFP, "+bbs_$bbsName.cgi") or $bbsEmpty = true;
	$i = 0;
	if ($bbsEmpty == false) {
		while (<BBSFP>) {
			if ($i == 0) {
				&puts("<dl>");
			}
			$i++;
			if ($i >= 10) {
				&puts("</dl>");
				last;
			}
			($no,$name,$subject,$message,$time) = split(/<>/);
			($min,$hour,$mday,$mon,$year,$wday) = (localtime($time))[1..6];
			$date = sprintf("%04d/%02d/%02d(%s) %02d:%02d",
						$year+1900,$mon+1,$mday,$week[$wday],$hour,$min);
			&puts(sprintf(qq(<dt><hr>[<strong>%d</strong>]<strong><font color="#006600">%s</font></strong> Ƽԡ<strong>%s</strong> %s</dt>),
					$no, $subject, $name, $date, $message));
			&puts(sprintf("<dd>%s</dd>", $message));
		}
	}
	close(BBSFP);
	&puts("<hr>");
};

$main::action_plugin{bbssubmit} = \&bbsSubmitAction;

sub bbsSubmitAction {
	my $title = $::form{p};

	my $name = $::form{name};
	my $subject = $::form{subject};
	my $bbsMessage = $::form{bbsMessage};
	$bbsMessage =~ s/&/&amp;/g;
	$bbsMessage =~ s/"/&quot;/g;
	$bbsMessage =~ s/>/&lt;/g;
	$bbsMessage =~ s/</&gt;/g;
	$bbsMessage =~ s/\r\n/<br>/g;
	$bbsMessage =~ s/\r/<br>/g;
	$bbsMessage =~ s/\n/<br>/g;

	my $dummyMessage = $::form{dummyMessage};
	my $bbsName = $::form{bbsName};

	if ("" ne $dummyMessage) {
		&action_view($title);
		return;
	}

	open(BBSSUBMITFP, "+<bbs_$bbsName.cgi") or open(BBSSUBMITFP, "+>bbs_$bbsName.cgi") or die("Can't BBS File Open.\n"); #'
	$| = 1; # FP Ф񤭹ߥХåե󥰤򤷤ʤ롣
	flock(BBSSUBMITFP, 2); # ¾å(2)
	seek(BBSSUBMITFP, 0, 0); # եݥ󥿤եƬ

	@bbsLines = <BBSSUBMITFP>;

	($no,$lastName,$lastSubject,$lastMessage) = (split(/<>/, $bbsLines[0]))[0,1,2,3];
	if ($lastName eq $name && $lastMessage eq $bbsMessage) {
		die("Ƥ϶ػߤǤ");
	}
	$no++;

	$ENV{'TZ'} = "JST-9";
	$time = time;

	unshift(@bbsLines, "$no<>$name<>$subject<>$bbsMessage<>$time\n");

	seek(BBSSUBMITFP, 0, 0); # եݥ󥿤եƬ
	print(BBSSUBMITFP @bbsLines);

	flock(BBSSUBMITFP, 8); # å(8)
	close(BBSSUBMITFP);

	&action_view($title);
};

;

==> bbsV0.6.zip: bbs.pl <==

$bbsMaxPage = 10;

# Υեޥå
@week = ('Sun','Mon','Tue','Wed','Thu','Fri','Sat');

$inline_plugin{bbs} = sub {
	my ($session, $bbsName) = @_;
	my %messages = ();
	my $page = $::form{bbspage};

	&puts(sprintf(qq(<form action='%s' method='POST'>
  <table border="0">
    <tr>
      <th align="right">̾</th>
      <td><input type="text" name="name" tabIndex="1"></td>
    </tr>
    <tr>
      <th align="right">̾</th>
      <td><input type="text" name="subject" size="50" tabIndex="2">
        <input type="submit" value="" tabIndex="4"></td>
    </tr>
    <tr>
      <th align="right" valign="top">å</th>
      <td><textarea name="bbsMessage" cols="40" rows="6" tabIndex="3"></textarea></td>
    </tr>
  </table>
  <input type="hidden" name="dummyMessage" value=""/>
  <input type="hidden" name="a" value="bbssubmit"/>
  <input type="hidden" name="bbsName" value="%s"/>
  <input type="hidden" name="p" value="%s"/>
  </form>), $::me, $bbsName, &enc($::form{p})));
	my $bbsEmpty = false;
	open(BBSFP, "+<bbs_$bbsName.cgi") or open(BBSFP, "+bbs_$bbsName.cgi") or $bbsEmpty = true;
	$i = 0;
	if ($bbsEmpty == false) {
		while (<BBSFP>) {
			if ($i == 0) {
				&puts("<dl>");
			}
			$i++;
			if ($i >= 10) {
				&puts("</dl>");
				last;
			}
			($no,$name,$subject,$message,$time) = split(/<>/);
			($min,$hour,$mday,$mon,$year,$wday) = (localtime($time))[1..6];
			$date = sprintf("%04d/%02d/%02d(%s) %02d:%02d",
						$year+1900,$mon+1,$mday,$week[$wday],$hour,$min);
			&puts(sprintf(qq(<dt><hr>[<strong>%d</strong>]<strong><font color="#006600">%s</font></strong> Ƽԡ<strong>%s</strong> %s</dt>),
					$no, $subject, $name, $date, $message));
			&puts(sprintf("<dd>%s</dd>", $message));
		}
	}
	close(BBSFP);
	&puts("<hr>");
};

$main::action_plugin{bbssubmit} = \&bbsSubmitAction;

sub bbsSubmitAction {
	my $title = $::form{p};

	my $name = $::form{name};
	$name =~ s/&/&amp;/g;
	$name =~ s/"/&quot;/g;
	$name =~ s/</&lt;/g;
	$name =~ s/>/&gt;/g;
	$name =~ s/\r\n/<br>/g;
	$name =~ s/\r/<br>/g;
	$name =~ s/\n/<br>/g;
	my $subject = $::form{subject};
	$subject =~ s/&/&amp;/g;
	$subject =~ s/"/&quot;/g;
	$subject =~ s/</&lt;/g;
	$subject =~ s/>/&gt;/g;
	$subject =~ s/\r\n/<br>/g;
	$subject =~ s/\r/<br>/g;
	$subject =~ s/\n/<br>/g;
	my $bbsMessage = $::form{bbsMessage};
	$bbsMessage =~ s/&/&amp;/g;
	$bbsMessage =~ s/"/&quot;/g;
	$bbsMessage =~ s/</&lt;/g;
	$bbsMessage =~ s/>/&gt;/g;
	$bbsMessage =~ s/\r\n/<br>/g;
	$bbsMessage =~ s/\r/<br>/g;
	$bbsMessage =~ s/\n/<br>/g;

	my $dummyMessage = $::form{dummyMessage};
	my $bbsName = $::form{bbsName};

	if ("" ne $dummyMessage) {
		&action_view($title);
		return;
	}

	open(BBSSUBMITFP, "+<bbs_$bbsName.cgi") or open(BBSSUBMITFP, "+>bbs_$bbsName.cgi") or die("Can't BBS File Open.\n"); #'
	$| = 1; # FP Ф񤭹ߥХåե󥰤򤷤ʤ롣
	flock(BBSSUBMITFP, 2); # ¾å(2)
	seek(BBSSUBMITFP, 0, 0); # եݥ󥿤եƬ

	@bbsLines = <BBSSUBMITFP>;

	($no,$lastName,$lastSubject,$lastMessage) = (split(/<>/, $bbsLines[0]))[0,1,2,3];
	if ($lastName eq $name && $lastMessage eq $bbsMessage) {
		die("Ƥ϶ػߤǤ");
	}
	$no++;

	$ENV{'TZ'} = "JST-9";
	$time = time;

	unshift(@bbsLines, "$no<>$name<>$subject<>$bbsMessage<>$time\n");

	seek(BBSSUBMITFP, 0, 0); # եݥ󥿤եƬ
	print(BBSSUBMITFP @bbsLines);

	flock(BBSSUBMITFP, 8); # å(8)
	close(BBSSUBMITFP);

	&action_view($title);
};

;
